
# Slot: source_file_date


modification date of the source of the schema

URI: [linkml:source_file_date](https://w3id.org/linkml/source_file_date)


## Domain and Range

schema_definition &#8594;  <sub>0..1</sub> datetime

## Parents


## Children


## Used by

 * schema_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | owl |

